==> huhk-1.9.5-py3-none-any.whl: service/app_a/funs/radarpoints/userpoints/funs_radarpoints_userpoints_exchangeinfo.py <==
import allure

from service.app_a.asserts.radarpoints.userpoints.asserts_radarpoints_userpoints_exchangeinfo import AssertsRadarpointsUserpointsExchangeinfo
from service.app_a.apis.radarpoints.userpoints import apis_radarpoints_userpoints_exchangeinfo


class FunsRadarpointsUserpointsExchangeinfo(AssertsRadarpointsUserpointsExchangeinfo):
    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def radarpoints_userpoints_exchangeinfo_pagelist(self, consigneeName="$None$", orderEndTime="$None$", goodsOrderId="$None$", userId="$None$", orderStartTime="$None$", mobile="$None$", current=1, size=10, _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/exchangeInfo/pageList
                params: size :  : 每页大小
                params: current :  : 当前页
                params: consigneeName :  : 收货人姓名
                params: goodsOrderId :  : 商品订单
                params: mobile :  : 收货人电话
                params: orderStartTime :  : 下单开始时间
                params: orderEndTime :  : 下单结束时间
                params: headers : 请求头
        """
        consigneeName = self.get_list_choice(consigneeName, list_or_dict=None, key="consigneeName")
        orderEndTime = self.get_list_choice(orderEndTime, list_or_dict=None, key="orderEndTime")
        goodsOrderId = self.get_list_choice(goodsOrderId, list_or_dict=None, key="goodsOrderId")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        orderStartTime = self.get_list_choice(orderStartTime, list_or_dict=None, key="orderStartTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints_exchangeinfo.radarpoints_userpoints_exchangeinfo_pagelist(**_kwargs)

        self.assert_radarpoints_userpoints_exchangeinfo_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)

==> huhk-2.1.5-py3-none-any.whl: service/app_a/funs/radarpoints/userpoints/funs_radarpoints_userpoints_exchangeinfo.py <==
import allure

from service.app_a.asserts.radarpoints.userpoints.asserts_radarpoints_userpoints_exchangeinfo import AssertsRadarpointsUserpointsExchangeinfo
from service.app_a.apis.radarpoints.userpoints import apis_radarpoints_userpoints_exchangeinfo


class FunsRadarpointsUserpointsExchangeinfo(AssertsRadarpointsUserpointsExchangeinfo):
    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def radarpoints_userpoints_exchangeinfo_pagelist(self, consigneeName="$None$", userId="$None$", size=10, orderStartTime="$None$", mobile="$None$", orderEndTime="$None$", goodsOrderId="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/exchangeInfo/pageList
                params: size :  : 每页大小
                params: current :  : 当前页
                params: consigneeName :  : 收货人姓名
                params: goodsOrderId :  : 商品订单
                params: mobile :  : 收货人电话
                params: orderStartTime :  : 下单开始时间
                params: orderEndTime :  : 下单结束时间
                params: headers : 请求头
        """
        consigneeName = self.get_list_choice(consigneeName, list_or_dict=None, key="consigneeName")
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        orderStartTime = self.get_list_choice(orderStartTime, list_or_dict=None, key="orderStartTime")
        mobile = self.get_list_choice(mobile, list_or_dict=None, key="mobile")
        orderEndTime = self.get_list_choice(orderEndTime, list_or_dict=None, key="orderEndTime")
        goodsOrderId = self.get_list_choice(goodsOrderId, list_or_dict=None, key="goodsOrderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints_exchangeinfo.radarpoints_userpoints_exchangeinfo_pagelist(**_kwargs)

        self.assert_radarpoints_userpoints_exchangeinfo_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)
